==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/bg-BG/admin/models/message.php <==
<?php

return array(

    'deleted' => 'Изтрит модел',
    'does_not_exist' => 'Моделът не съществува.',
    'no_association' => 'ВНИМАНИЕ! Модела за този актив е неправилен или липсва!',
    'no_association_fix' => 'Това ще счупи нещата по много лош начин. Редактирайте артикула сега и го зачислете към модел.',
    'assoc_users'	 => 'Този модел е асоцииран с един или повече активи и не може да бъде изтрит. Моля изтрийте активите и опитайте отново.',
    'invalid_category_type' => 'The category must be an asset category.',

    'create' => array(
        'error'   => 'Моделът не беше създаден. Моля опитайте отново.',
        'success' => 'Моделът създаден успешно.',
        'duplicate_set' => 'Актив с това име, производител и номер на модел вече е въведен.',
    ),

    'update' => array(
        'error'   => 'Моделът не беше обновен. Моля опитайте отново.',
        'success' => 'Моделът обновен успешно.',
    ),

    'delete' => array(
        'confirm'   => 'Желаете ли изтриване на модела?',
        'error'   => 'Проблем при изтриване на модела. Моля опитайте отново.',
        'success' => 'Моделът изтрит успешно.'
    ),

    'restore' => array(
        'error'   		=> 'Моделът не беше възстановен. Моля опитайте отново.',
        'success' 		=> 'Моделът възстановен успешно.'
    ),

    'bulkedit' => array(
        'error'   		=> 'Няма полета, който да са се променили, така че нищо не е осъвременено.',
        'success' 		=> 'Модела е обновен успешно. |:model_count модела са обновени успешно.',
        'warn'          => 'Вие ще обновите характиристиките на следния модел: |Вие ще редактирате характеристиките на следните :model_count модела:',

    ),

    'bulkdelete' => array(
        'error'   		    => 'Няма избрани модели, така че нищо не бе изтрито.',
        'success' 		    => 'Модела е изтрит!|:success_count модела бяха изтрити!',
        'success_partial' 	=> ':success_count модела бяха изтрити, но :fail_count не бяха, тъй като към тях има асоциирани активи.'
    ),

);

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/bg-BG/admin/models/message.php <==
<?php

return array(

    'deleted' => 'Изтрит модел',
    'does_not_exist' => 'Моделът не съществува.',
    'no_association' => 'ВНИМАНИЕ! Модела за този актив е неправилен или липсва!',
    'no_association_fix' => 'Това ще счупи нещата по много лош начин. Редактирайте артикула сега и го зачислете към модел.',
    'assoc_users'	 => 'Този модел е асоцииран с един или повече активи и не може да бъде изтрит. Моля изтрийте активите и опитайте отново.',
    'invalid_category_type' => 'This category must be an asset category.',

    'create' => array(
        'error'   => 'Моделът не беше създаден. Моля опитайте отново.',
        'success' => 'Моделът създаден успешно.',
        'duplicate_set' => 'Актив с това име, производител и номер на модел вече е въведен.',
    ),

    'update' => array(
        'error'   => 'Моделът не беше обновен. Моля опитайте отново.',
        'success' => 'Моделът обновен успешно.',
    ),

    'delete' => array(
        'confirm'   => 'Желаете ли изтриване на модела?',
        'error'   => 'Проблем при изтриване на модела. Моля опитайте отново.',
        'success' => 'Моделът изтрит успешно.'
    ),

    'restore' => array(
        'error'   		=> 'Моделът не беше възстановен. Моля опитайте отново.',
        'success' 		=> 'Моделът възстановен успешно.'
    ),

    'bulkedit' => array(
        'error'   		=> 'Няма полета, който да са се променили, така че нищо не е осъвременено.',
        'success' 		=> 'Модела е обновен успешно. |:model_count модела са обновени успешно.',
        'warn'          => 'Вие ще обновите характиристиките на следния модел: |Вие ще редактирате характеристиките на следните :model_count модела:',

    ),

    'bulkdelete' => array(
        'error'   		    => 'Няма избрани модели, така че нищо не бе изтрито.',
        'success' 		    => 'Модела е изтрит!|:success_count модела бяха изтрити!',
        'success_partial' 	=> ':success_count модела бяха изтрити, но :fail_count не бяха, тъй като към тях има асоциирани активи.'
    ),

);
